import requests
from py3_infobip.models import SmsTextSimpleBody


class InfobipService:
    def __init__(self, url: str, api_key: str, **kwargs):
        super().__init__()
        self._sesion = requests.Session()
        url = (url or '').strip()
        url = url if url[-1:] != '/' else url[:-1]
        self._url = url
        self._api_key = api_key
        self._auth_prefix = kwargs.get('auth_prefix', 'App')
        self._content_type = kwargs.get('content_type', 'application/json')
        self._sesion.headers.update({'Authorization': f'{self._auth_prefix} {self._api_key}'})
        self._sesion.headers.update({'Content-Type': f'{self._content_type}'})
        self._sesion.headers.update({'accept': 'application/json'})

    def _post(self, method_url: str, body: dict, options: dict = {}):
        return self._sesion.post(url=f'{self._url}/{method_url}', json=body, **options)


class SmsClient(InfobipService):
    def send_sms_text_simple(self, body: SmsTextSimpleBody):
        return self._post('sms/1/text/single', body.to_dict())



from typing import List
from py3_infobip.utils.u_dict import clean_null_terms


class SmsTextSimpleBody:
    def __init__(self, **kwargs):
        super().__init__()
        self._from: str = kwargs.get('ffrom', None)
        self._to: List[str] = kwargs.get('to', None)
        self._text: str = kwargs.get('text', None)

    @property
    def ffrom(self):
        return self._from

    @property
    def to(self):
        return self._to

    @property
    def text(self):
        return self._text

    def set_ffrom(self, value: str):
        self._from = value
        return self

    def set_to(self, value: List[str]):
        self._to = value
        return self

    def set_text(self, value: str):
        self._text = value
        return self

    def to_dict(self, with_null_values=False):
        json_value = {
            'from': self.ffrom,
            'to': self.to,
            'text': self.text
        }
        if with_null_values is True:
            return json_value
        return clean_null_terms(json_value)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['py3_infobip', 'py3_infobip.utils']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.23.0,<3.0.0']

setup_kwargs = {
    'name': 'py3-infobip',
    'version': '0.0.3',
    'description': '',
    'long_description': None,
    'author': 'Nicolas Cardenas',
    'author_email': 'nicolas.cardenas722@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nico722/infobip-python3-client',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
